@@ -1,6 +1,6 @@
 use std::convert::TryInto;
 
-use clap::{App, Arg, ArgMatches};
+use clap::{Arg, ArgMatches, Command};
 use miette::Result;
 use mit_commit_message_lints::{
     console::style::to_be_piped,
@@ -10,8 +10,8 @@ use mit_commit_message_lints::{
 
 use crate::{current_dir, get_vcs};
 
-pub fn app<'help>() -> App<'help> {
-    App::new("generate")
+pub fn cli<'help>() -> Command<'help> {
+    Command::new("generate")
         .arg(
             Arg::new("scope")
                 .long("scope")
